import React, { useCallback, useEffect, useRef, useState } from 'react';
import { Utils } from '../util';
import { useIntersection } from '../util/hooks/useIntersection';
import './skillbar.css';
import { useIsServer } from '../util/hooks/useIsServer';
const SkillBar = ({ skills, colors, offset = `25px`, height = 35, animationDuration = 3000, animationDelay = 1000, animationThreshold = 0.8, }) => {
    let intersection = null;
    const ref = useRef(null);
    const [isCollapsed, setIsCollapsed] = useState(true);
    const isServer = useIsServer();
    intersection = useIntersection(ref, {
        root: null,
        rootMargin: offset,
        threshold: animationThreshold,
    }, isServer);
    useEffect(() => {
        if (intersection && intersection.isIntersecting) {
            const timer = setTimeout(() => setIsCollapsed(false), animationDelay);
            return () => clearTimeout(timer);
        }
    }, [intersection]);
    const getSkillBarColor = useCallback((skill, index) => {
        if (skill.color && skill.color.bar && Utils.isString(skill.color.bar)) {
            return skill.color.bar;
        }
        else if (colors && colors.bar) {
            if (Utils.isString(colors.bar)) {
                return colors.bar;
            }
            return Utils.getHSL(colors.bar, index, skills.length);
        }
        return '';
    }, []);
    const getTitleColor = useCallback((skill, index, entry) => {
        if (skill.color &&
            skill.color.title &&
            skill.color.title[entry] &&
            Utils.isString(skill.color.title[entry])) {
            return skill.color.title[entry];
        }
        else if (colors && colors.title && colors.title[entry]) {
            if (Utils.isString(colors.title[entry])) {
                return colors.title[entry];
            }
            return Utils.getHSL(colors.title[entry], index, skills.length);
        }
        return '';
    }, []);
    return (React.createElement("div", { "data-testid": 'skillbar/root', ref: ref }, skills.map((skill, index) => (React.createElement("div", { key: skill.type, className: "skillbar", "data-testid": 'skillbar/container', style: {
            height: `${Utils.getHeight(height)}`,
            lineHeight: `${Utils.getHeight(height)}`,
        } },
        React.createElement("div", { className: "skillbar-title", "data-testid": 'skillbar/title', style: {
                color: `${getTitleColor(skill, index, 'text')}`,
                background: `${getTitleColor(skill, index, 'background')}`,
            } },
            React.createElement("span", null, skill.type)),
        React.createElement("div", { "data-testid": 'skillbar/bar', className: `skillbar-bar ${isCollapsed ? 'collapsed' : ''}`, style: {
                background: `${getSkillBarColor(skill, index)}`,
                width: `calc((100% - 110px) * (${skill.level} * 0.01))`,
                transition: `width ${animationDuration}ms ease-in-out`,
            } }),
        React.createElement("div", { className: "skillbar-percent", "data-testid": 'skillbar/percent' },
            skill.level,
            "%"))))));
};
export default SkillBar;
