import { useEffect, useState } from 'react';
export const useIntersection = (ref, options, isServer) => {
    const [intersectionObserverEntry, setIntersectionObserverEntry] = useState(null);
    useEffect(() => {
        if (!isServer &&
            ref.current &&
            typeof IntersectionObserver === 'function') {
            const handler = (entries) => {
                setIntersectionObserverEntry(entries[0]);
            };
            const observer = new IntersectionObserver(handler, options);
            observer.observe(ref.current);
            return () => {
                setIntersectionObserverEntry(null);
                observer.disconnect();
            };
        }
        return () => {
            return;
        };
    }, [ref.current, options.threshold, options.root, options.rootMargin]);
    return intersectionObserverEntry;
};
